<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Services\Admin\AgentService;
use Yajra\DataTables\DataTables;
use Illuminate\Validation\Rule;

class AgentController extends Controller
{
    protected $agent;

    public function __construct(AgentService $agentService)
    {
        parent::__construct();
        $this->agent = $agentService;
    }

    public function index()
    {
        $data = $this->agent->getAll();
        return DataTables::of($data)->make();
    }

    public function register(Request $request)
    {
        $request->validate([
            'agent_code' => 'required|unique:agents,agent_code',
            'email' => 'required',
            'phone_number' => 'required',
            'address' => 'required',
            'birth' => 'required',
            'username' => 'required',
            'password' => 'required'
        ]);

        $this->response->data = $this->agent->register($request->agent_code, $request->email, $request->phone_number, $request->address, $request->birth, $request->username, $request->password);
        $this->response->message = __('resources.create_success');
        return $this->json();
    }

    public function detail($id)
    {
        $this->response->data = $this->agent->getDataById($id);
        return $this->json();
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'agent_code' => [
                'required',
                Rule::unique('agents', 'agent_code')->ignore($id)
            ],
            'username' => 'required|string',
            'email' => 'required',
            'phone_number' => 'required',
            'address' => 'required',
            'birth' => 'required'
        ]);

        $this->agent->updateData(
            $id,
            $request->referral_pam_id,
            $request->agent_code,
            $request->email,
            $request->phone_number,
            $request->address,
            $request->birth,
            $request->username
        );
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function update_password(Request $request, $id)
    {
        $request->validate([
            'password' => 'required'
        ]);

        $this->agent->updatePassword($id, $request->password);
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function disable(Request $request, $id)
    {
        $this->agent->disableData($id);
        $this->response->message = __('resources.disable_success');
        return $this->json();
    }

    public function restore($id)
    {
        $this->agent->restoreData($id);
        $this->response->message = __('resources.restore_success');
        return $this->json();
    }

    public function index_new()
    {
        $data = $this->agent->getAllNotVerified();
        return DataTables::of($data)->make();
    }

    public function approve($id)
    {
        $this->agent->approve($id);
        $this->response->message = __('resources.approve_success');
        return $this->json();
    }

    public function reject($id)
    {
        $this->agent->reject($id);
        $this->response->message = __('resources.reject_success');
        return $this->json();
    }
}
