<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use App\Services\Admin\MenuService;

class MenuController extends Controller
{
    protected $menu;

    public function __construct(MenuService $menuService) {
        parent::__construct();
        $this->menu = $menuService;
    }

    public function index(){
        $data = $this->menu->getAll();
        return DataTables::of($data)->make(); 
    }

    public function store(Request $request){
        $request->validate([
            'menu_type_id' => 'required',
            'name' => 'required',
            'parent_id' => 'required',
            'position' => 'required',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $this->menu->createData($request->name, $request->menu_type_id, $request->parent_id, $request->position, $request->description, $request->file('image'), $request->file('document'));
        $this->response->message = __('resources.create_success');
        return $this->json();
    }

    public function detail(Request $request, $id){
        $this->response->data = $this->menu->getDataById($id);
        return $this->json();
    }

    public function update(Request $request, $id){
        $request->validate([
            'name' => 'required',
            'position' => 'required',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $this->menu->updateData($id, $request->name, $request->menu_type_id, $request->parent_id, $request->position, $request->description, $request->file('image'), $request->file('document'));
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function delete($id){
        $this->menu->deleteData($id);
        $this->response->message = __('resources.delete_success');
		return $this->json();
    }

    public function child_menu($id){
        $data = $this->menu->childMenu($id);
        return DataTables::of($data)->make(); 
		return $this->json();
    }

    public function description_image(Request $request)
    {
        $this->response->data = $this->menu->storeDescription($request->file);
        $this->response->message = __('resources.create_success');
        return $this->json();
    }
}
