<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use App\Services\Admin\NotificationService;

class NotificationController extends Controller
{
    protected $notification;

    public function __construct(NotificationService $notificationService) {
        parent::__construct();
        $this->notification = $notificationService;
    }

    public function index(){
        $data = $this->notification->getAll();
        return DataTables::of($data)->make(); 
    }

    public function store(Request $request){
        $request->validate([
            'title' => 'required',
            'body' => 'required',
            'banner' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048'
        ]);

        $this->response->data = $this->notification->createData($request->title, $request->body, $request->file('banner'));
        $this->response->message = __('resources.create_success');
        return $this->json();
    }

    public function detail($id){
        $this->response->data = $this->notification->getDataById($id);
        return $this->json();
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'title' => 'required',
            'body' => 'required',
            'banner' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048'
        ]);
               
        $this->notification->updateData($id, $request->title, $request->body, $request->file('banner'));
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function delete($id){
        $this->notification->deleteData($id);
        $this->response->message = __('resources.delete_success');
		return $this->json();
    }

    public function send_android($id){
        $this->notification->pushNotificationAndroid($id);
        $this->response->message = __('resources.success_send_notification');
		return $this->json();
    }

    public function send_ios($id){
        $this->notification->pushNotificationIos($id);
        $this->response->message = __('resources.success_send_notification');
		return $this->json();
    }
}
