<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;
use App\Services\Admin\AuthService;
use Illuminate\Validation\Rule;

class UserController extends Controller
{
    protected $auth;

    public function __construct(AuthService $authService) {
        parent::__construct();
        $this->auth = $authService;
    }

    public function index()
    {
        $data = $this->auth->getAll();
		return DataTables::of($data)->make();
    }

    public function login(Request $request)
    {
        $request->validate([
            'username' => 'required|string',
            'password' => 'required|string'
        ]);

        $this->response->data = $this->auth->login($request->username, $request->password);
        return $this->json();
    }

    public function register(Request $request)
    {
        $request->validate([
            'username' => 'required|unique:users,username',
            'password' => 'required'
        ]);

        $this->response->data = $this->auth->createData($request->username, $request->password);
        return $this->json();
    }

    public function logout()
    {
        $user = request()->user(); 
        $user->tokens()->where('id', $user->currentAccessToken()->id)->delete();

        $this->response->message = "You have successfully logged out and the token was successfully deleted";
        return $this->json();
    }

    public function detail($id)
    {
        $this->response->data = $this->auth->getDataById($id);
        return $this->json();
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'username' => [
                'required',
                Rule::unique('users', 'username')->ignore($id)
            ],
            'password' => 'required'
        ]);

        $this->auth->updateData($id, $request->username, $request->password);
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function disable($id){
        $this->auth->disableData($id);
        $this->response->message = __('resources.disable_success');
		return $this->json();
    }

    public function restore($id){
        $this->auth->restoreData($id);
        $this->response->message = __('resources.restore_success');
		return $this->json();
    }
}
