<?php

namespace App\Http\Controllers\Agent;

use App\Http\Controllers\Controller;
use App\Http\Resources\HistoryAgentResources;
use App\Models\HistoryAgent;
use App\Models\Schedule;
use Illuminate\Http\Request;
use Carbon\Carbon;

class HistoryAgentController extends Controller
{
    public function index()
    {
        $result = HistoryAgent::all();
        $this->response->data = HistoryAgentResources::collection($result);
        return $this->json();
    }

    public function scan(Request $request, Schedule $schedule)
    {
        $check = $schedule->history_agents()
            ->where('agent_id', auth()->user()->id)
            ->orderBy('id', 'desc')
            ->first();

        if(empty($check)){
            $data = [
                'schedule' => $schedule,
                'status_check' => 1,
            ];

            $this->response->data = $data;
            return $this->json();
        }

        if ($check->status_check) {
            $time_check = Carbon::parse($check->time_check)->format('d');
            $today = Carbon::parse(Carbon::now())->format('d');

            $checkDayScan = $time_check < $today ? true : false;
            if ($checkDayScan) {
                // Check in
                $data = [
                    'schedule' => $schedule,
                    'status_check' => 1,
                ];

                $this->response->data = $data;
            } else {
                // Check out
                $data = [
                    'schedule' => $schedule,
                    'status_check' => 0,
                ];

                $this->response->data = $data;
            }
        } else {
            // Check in
            $data = [
                'schedule' => $schedule,
                'status_check' => 1,
            ];

            $this->response->data = $data;
        }

        return $this->json();
    }

    public function check(Request $request, Schedule $schedule, $status)
    {
        $scheduleTime = Carbon::parse($schedule->time)->addMinutes(15);
        $today = Carbon::now();
        
        if($scheduleTime->gt($today) || !$status){
            $historyAgent = new HistoryAgent();
            $historyAgent->agent_id = auth()->user()->id;
            $historyAgent->schedule_id = $schedule->id;
            $historyAgent->status_check = $status ? 1 : 0;
            $historyAgent->time_check = $today;
            $historyAgent->save();
        } else {
            $this->code = 404;
            $this->response->status = false;
            $this->response->message = "Sorry can't scan because it's past the time limit";
        }

        return $this->json();
    }

    public function history_check(Request $request, $limit)
    {
        $result = HistoryAgent::where('agent_id', '=', auth()->user()->id)
        ->join('schedules', 'schedules.id', '=', 'history_agents.schedule_id')
        ->skip($limit * 10 - 10)
        ->take($limit * 10)
        ->select('history_agents.id', 'history_agents.status_check', 'history_agents.time_check as history_time_check', 'schedules.title', 'schedules.time as schedule_time')
        ->orderBy('history_agents.created_at', 'desc')
        ->get();

        $this->response->data = $result;
        return $this->json();
    }
}
