<?php

namespace App\Http\Controllers\Landing;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use App\Mail\ForgotPassword;
use App\Models\Agent;
use Illuminate\Support\Facades\Validator;
use Psr\Log\LoggerInterface;
use Illuminate\Support\Facades\Log;

class MailController extends Controller
{
    /**
     * @var LoggerInterface
     */
    protected $logger;

    public function __construct() {
        parent::__construct();
        $this->logger = Log::channel('landing-mailController');
    }

    public function forget_password(Request $request){
        $rules = [
            'email' => 'required',
        ];

        try {
            $validator = Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                $this->code = 400;
                $this->response->status = false;
                $this->response->message = $validator->errors()->first();
                $this->response->errors = $validator->fails();

                $this->logger->error($validator->errors()->first());
                return $this->json();
            }
            
            $agent = Agent::where('email', $request->email)->first();
    
            if(!is_null($agent)){
                $url = 'https://verification-kiseki.myxplore.cc/#/verification_password/'.$agent->id;
                Mail::to($agent->email)->send(new ForgotPassword($agent, $url));
    
                $this->response->message = __('resources.create_success');
            } else {
                $this->code = 400;
                $this->response->status = false;
                $this->response->message = __('resources.not_found');  
    
                $this->logger->error(__('resources.not_found'));
                return $this->json(); 
            }
        } catch(\Exception $e) {
            $this->code = 500;
            $this->logger->error($e->getMessage());
            $this->response->message = __('resources.create_failed');
        }

        return $this->json();
    }

    public function verification_forget_password(Request $request, $agent){
        try {
            $data = Agent::where('id', $agent)->first();

            if($data) {
                $data->password = bcrypt($request->password);
                $data->save();

                $this->response->message = __('resources.update_success');
            } else {
                $this->code = 400;
                $this->response->status = false;
                $this->response->message = __('resources.not_found');  
    
                $this->logger->error(__('resources.not_found'));
                return $this->json();   
            }
        } catch(\Exception $e) {
            $this->code = 500;
            $this->logger->error($e->getMessage());
            $this->response->message = __('resources.update_failed');
        }
        
		return $this->json();
    }
}
