<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Support\Facades\Route;
use Spatie\Permission\Exceptions\PermissionDoesNotExist;

class AccessCheck
{
    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     * @return mixed
     */
    public function handle($request, Closure $next, $guard)
    {
        $user = $request->user();
        $permission = Route::currentRouteName();

        try{
            if (!$user->hasPermissionTo($permission, $guard)){
                return $this->generate_response($request, new PermissionDoesNotExist(__('validation.permission.authorize')));
            }
        }catch (PermissionDoesNotExist $pdne){
            return $this->generate_response($request, new PermissionDoesNotExist(__('validation.permission.not_found',
                ['permission' => $permission])));
        }
        return $next($request);
    }

    /**
     * @param  \Illuminate\Http\Request  $request
     * @param \Exception $exception
     * @return mixed
     */
    protected function generate_response($request, $exception){
        if($request->ajax()){
            return response()->json([
                'data'=> '',
                'message'=> $exception->getMessage(),
                'status'=> false
            ], 403);
        }

        abort(403, $exception->getMessage());
    }
}
