<?php


namespace App\Lib\Alerting\Provider\Entity;

use App\Services\Exception\ServiceException;
use Illuminate\Validation\ValidationException;
use Illuminate\Support\Facades\Request;

class Discord
{
    const MAXIMUM_VALUE_FIELD = 270;

    const COLOR = 16734296;

    public $username;

    public $embeds;

    public function __construct()
    {
        $this->username = sprintf(
            "%s(%s)",
            config('app.name'),
            config('app.env')
        );
        $this->embeds = [];
    }

    /**
     * @return Discord
     */
    public static function with()
    {
        return new self();
    }

    /**
     * @param  \Throwable  $exception
     */
    public function setEmbeds($exception): Discord
    {
        $this->embeds = $this->refactorEmbeds($exception);

        return $this;
    }

    public function toArray()
    {
        return [
            'username' => $this->username,
            'embeds'   => $this->embeds
        ];
    }

    /**
     * @param  \Throwable  $exception
     */
    public function refactorEmbeds($exception): array
    {
        if (!$exception instanceof ServiceException && !$exception instanceof ValidationException) {
            $url = substr(Request::url(), strpos(Request::url(), "/api/") + 1) ;
            $errorMessage = $exception->getMessage();
            $locationFile = $exception->getFile();
            $errorLine = $exception->getLine();

            return [
                (object) [
                    'color'  => self::COLOR,
                    'title'  => "Error",
                    'description' => "
                        API: /{$url} \r
                        Error Message: $errorMessage \r
                        Full Location: $locationFile:$errorLine \r
                    ",
                ]
            ];
        }
        return [];
    }
}
