<?php

namespace App\Repositories\Admin;

use App\Models\HistoryAgent;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\DataTables;

class HistoryRepository
{
    private $model;

    public function __construct(HistoryAgent $model)
    {
        $this->model = $model;
    }

    public function getAll($startDate, $endDate)
    {
        return $this->model->with(['schedule', 'agent'])
            ->whereHas('schedule', function ($q) use ($startDate, $endDate) {
                return $q->whereBetween('time', [$startDate, $endDate]);
            })
            ->where('status_check', 1)
            ->groupBy(['agent_id', 'schedule_id'])
            ->orderBy('created_at', 'desc');
    }

    public function detail_person($agent_id, $start_date, $end_date)
    {
        $dataSchedule = $this->model->with(['schedule' => function ($query) use ($start_date, $end_date) {
            $query->whereBetween('time', [$start_date, $end_date]);
        }])
            ->where([
                ['agent_id', $agent_id]
            ])
            ->whereBetween('created_at', [$start_date, $end_date])
            ->get();
        $dataPerson = $this->model->where('agent_id', $agent_id)->first();
        $resultPerson = $dataPerson->agent()->first();

        return [
            'dataSchedule' => $dataSchedule,
            'dataPerson' => $resultPerson
        ];
    }

    public function getDataById($agent_id, $start_date, $end_date)
    {
        return $this->model->with(['schedule' => function ($query) use($start_date, $end_date) {
            $query->whereBetween('time', [$start_date, $end_date]);
        }, 'agent'])
            ->where([
                ['agent_id', $agent_id]
            ])
            ->whereBetween('created_at', [$start_date, $end_date])
            ->get();
    }

    public function getDataAttendance()
    {
        $data = $this->model
            ->join('agents', 'history_agents.agent_id', 'agents.id')
            ->select(DB::raw("agent_id, schedule_id, username"))
            ->where('status_check', 0)
            ->groupBy(['agent_id', 'schedule_id']);

        $data2 = DB::table(DB::raw("({$data->toSql()}) as sub"))
            ->mergeBindings($data->getQuery()) // you need to get underlying Query Builder
            ->select(DB::raw("agent_id, username, count(*) as total"))
            ->groupBy(['agent_id']);

        return DataTables::of($data2)
            ->make();
    }

    public function getDataAttendanceDetail($agent_id)
    {
        $data = $this->model->where('agent_id', $agent_id)
            ->where('status_check', 0)
            ->groupBy(['schedule_id']);

        return DataTables::of($data)
            ->addColumn('schedule', function (HistoryAgent $history_agents) {
                $schedule = $history_agents->schedule()->first();
                return $schedule->title;
            })
            ->addColumn('date', function (HistoryAgent $history_agents) {
                $schedule = $history_agents->schedule()->first();
                return $schedule->time;
            })
            ->make();
    }
}
