<?php

namespace App\Services\Admin;

use App\Repositories\Admin\AgentRepository;
use App\Services\Exception\ServiceException;

class AgentService
{
    protected $agent;

    const DISABLE = "DISABLE";
    const RESTORE = "RESTORE";
    const APPROVE = "APPROVE";
    const REJECT = "REJECT";

    public function __construct(AgentRepository $agent)
    {
        $this->agent = $agent;
    }

    public function getAll()
    {
        return $this->agent->getAll();
    }

    public function register($agent_code, $email, $phone_number, $address, $birth, $username, $password)
    {
        return $this->agent->register($agent_code, $email, $phone_number, $address, $birth, $username, $password);
    }

    public function getDataById($id)
    {
        $data = $this->checkAvailability($id);
        return $data;
    }

    public function updateData(
        $id,
        $referral_pam_id,
        $agent_code,
        $email,
        $phone_number,
        $address,
        $birth,
        $username,
    ) {
        $this->checkAvailability($id);
        return $this->agent->update(
            $id,
            $referral_pam_id,
            $agent_code,
            $email,
            $phone_number,
            $address,
            $birth,
            $username
        );
    }

    public function updatePassword($id, $password)
    {
        $this->checkAvailability($id);
        return $this->agent->updatePassword($id, $password);
    }

    public function disableData($id)
    {
        $this->checkAvailability($id, self::DISABLE);
        return $this->agent->disable($id);
    }

    public function restoreData($id)
    {
        $this->checkAvailability($id, self::RESTORE);
        return $this->agent->restore($id);
    }

    public function getAllNotVerified()
    {
        return $this->agent->indexNotVerified();
    }

    public function approve($id)
    {
        $this->checkAvailability($id, self::APPROVE);
        return $this->agent->approve($id);
    }

    public function reject($id)
    {
        $this->checkAvailability($id, self::REJECT);
        return $this->agent->reject($id);
    }

    public function checkAvailability($id, $check = null)
    {
        $data = $this->agent->detail($id);
        if (is_null($data)) {
            throw new ServiceException('000');
        } else if (!is_null($data->deleted_at) && $check === self::DISABLE) {
            throw new ServiceException('001');
        } else if (is_null($data->deleted_at) && $check === self::RESTORE) {
            throw new ServiceException('002');
        } else if ($data->verified === 1 && $check === self::APPROVE) {
            throw new ServiceException('003');
        } else if ($data->verified === 1 && $check === self::REJECT) {
            throw new ServiceException('003');
        }

        return $data;
    }
}
