<?php

namespace App\Services\Admin;

use App\Repositories\Admin\AuthRepository;
use App\Services\Exception\ServiceException;
use Illuminate\Support\Facades\Hash;

class AuthService
{
    protected $auth;

    const DISABLE = "DISABLE";
    const RESTORE = "RESTORE";

    public function __construct(AuthRepository $auth)
    {
        $this->auth = $auth;
    }

    public function getAll()
    {
        return $this->auth->index();
    }

    public function login($username, $password) {
        $user = $this->auth->getDataByUsername($username);

        if (!$user || !Hash::check($password, $user->password)) {
            throw new ServiceException('100');
        }

        $token = $user->createToken('myapptoken')->plainTextToken;

        return [
            'user' => $user,
            'role' => $user->getRoleNames()->first(),
            'token' => $token
        ];
    }

    public function createData($username, $password)
    {
        return $this->auth->create($username, $password);
    }

    public function getDataById($id)
    {
        $data = $this->checkAvailability($id);
        return $data;
    }

    public function updateData($id, $username, $password)
    { 
        $this->checkAvailability($id);
        return $this->auth->update($id, $username, $password);
    }

    public function disableData($id)
    {
        $this->checkAvailability($id, self::DISABLE);
        return $this->auth->disable($id);
    }

    public function restoreData($id)
    {
        $this->checkAvailability($id, self::RESTORE);
        return $this->auth->restore($id);
    }

    public function checkAvailability($id, $check = null)
    {
        $data = $this->auth->detail($id);
        if(is_null($data)){
            throw new ServiceException('000');
        } else if (!is_null($data->deleted_at) && $check === self::DISABLE){
            throw new ServiceException('001');
        } else if(is_null($data->deleted_at) && $check === self::RESTORE) {
            throw new ServiceException('002');
        } 

        return $data;
    }
}
