<?php

namespace App\Services\Admin;

use App\Repositories\Admin\AgentRepository;
use App\Repositories\Admin\ScheduleRepository;
use App\Services\Exception\ServiceException;
use Carbon\Carbon;
use File;

class ScheduleService
{
    protected $schedule;

    protected $agent;

    public function __construct(
        ScheduleRepository $schedule,
        AgentRepository $agent
    ) {
        $this->schedule = $schedule;
        $this->agent = $agent;
    }

    public function getAll()
    {
        return $this->schedule->getAll();
    }

    public function createData(
        $title,
        $speaker,
        $description,
        $banner,
        $time
    ) {
        $fileBanner = time() . '.' . $banner->getClientOriginalExtension();
        $banner->move(public_path('schedule'), $fileBanner);

        return $this->schedule->createData(
            $title,
            $speaker,
            $description,
            $fileBanner,
            $time
        );
    }

    public function getDataById($id)
    {
        $data = $this->checkAvailability($id);
        return $data;
    }

    public function updateData(
        $id,
        $title,
        $speaker,
        $description,
        $banner,
        $time
    ) {
        $data = $this->checkAvailability($id);
        if (!empty($banner)) {
            if (!empty($data->banner)) {
                File::delete(public_path('schedule/' . $data->banner));
            }

            $fileBanner = time() . '.' . $banner->getClientOriginalExtension();
            $banner->move(public_path('schedule'), $fileBanner);
        }

        return $this->schedule->updateData(
            $id,
            $title,
            $speaker,
            $description,
            !empty($banner) ? $fileBanner : $data->banner,
            $time
        );
    }

    public function deleteData($id)
    {
        $data = $this->checkAvailability($id);
        if (File::exists(public_path('schedule/' . $data->banner))) {
            File::delete(public_path('schedule/' . $data->banner));
        }

        return $this->schedule->deleteData($id);
    }

    public function getDataAnalystHistory($startDate, $endDate)
    {
        return $this->schedule->getDataAnalystHistory($startDate, $endDate);
    }

    public function getDataAnalystHistoryById($id)
    {
        $this->checkAvailability($id);
        $data = $this->schedule->getDataAnalystHistoryById($id);
        $result = $this->checkAttendanceTraining($data);
        
        return $this->unique_array($result);
    }

    public function getDataAnalystHistoryFilter($startDate, $endDate)
    {
        return $this->schedule->getDataAnalystHistoryFilter($startDate, $endDate);
    }

    public function getDataChart()
    {
        $data = $this->schedule->getAll()->get();
        $myArray = [
            (object) [
                'month' => 'January',
                'total' => 0
            ],
            (object) [
                'month' => 'February',
                'total' => 0
            ],
            (object) [
                'month' => 'March',
                'total' => 0
            ],
            (object) [
                'month' => 'April',
                'total' => 0
            ],
            (object) [
                'month' => 'May',
                'total' => 0
            ],
            (object) [
                'month' => 'June',
                'total' => 0
            ],
            (object) [
                'month' => 'July',
                'total' => 0
            ],
            (object) [
                'month' => 'August',
                'total' => 0
            ],
            (object) [
                'month' => 'September',
                'total' => 0
            ],
            (object) [
                'month' => 'Oktober',
                'total' => 0
            ],
            (object) [
                'month' => 'November',
                'total' => 0
            ],
            (object) [
                'month' => 'December',
                'total' => 0
            ],
        ];

        foreach ($data as $dt) {
            $month = Carbon::parse($dt->time)->format('F');
            $agentLogin = $dt->history_agents->groupBy('status_check');

            $checkIn = isset($agentLogin[1]) ? count($agentLogin[1]) : 0;
            $checkOut = isset($agentLogin[0]) ? count($agentLogin[0]) : 0;
            $totalAgentCheck = (floor(($checkIn + $checkOut) / 2));

            foreach ($myArray as $checkDate) {
                if ($checkDate->month === $month) {
                    $checkDate->total += $totalAgentCheck;
                }
            }
        }

        return $myArray;
    }

    public function pushNotificationAndroid($id)
    {
        $SERVER_KEY = config('app.google_secret_android');

        $detailSchedule = $this->checkAvailability($id);
        $agents = $this->agent->getAll()->get();
        foreach ($agents as $agent) {
            $DEVICE_TOKEN = $agent->device_token;
            $data = [
                "to" => $DEVICE_TOKEN,
                "notification" => [
                    "title" => $detailSchedule->title,
                    "body" => $detailSchedule->description,
                ],
                "data" => [
                    "type" => "schedule",
                    "id" => $detailSchedule->id
                ]
            ];
            $dataString = json_encode($data);

            $headers = [
                'Authorization: key=' . $SERVER_KEY,
                'Content-Type: application/json',
            ];

            $ch = curl_init();

            curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);

            curl_exec($ch);
            curl_close($ch);
        }

        return true;
    }

    public function pushNotificationIos($id)
    {
        $SERVER_KEY = config('app.google_secret_ios');

        $detailSchedule = $this->checkAvailability($id);
        $agents = $this->agent->getAll()->get();

        foreach ($agents as $agent) {
            $DEVICE_TOKEN = $agent->device_token;

            $data = [
                "to" => $DEVICE_TOKEN,
                "notification" => [
                    "title" => $detailSchedule->title,
                    "body" => $detailSchedule->description,
                ],
                "data" => [
                    "type" => "schedule",
                    "id" => $detailSchedule->id
                ]
            ];
            $dataString = json_encode($data);

            $headers = [
                'Authorization: key=' . $SERVER_KEY,
                'Content-Type: application/json',
            ];

            $ch = curl_init();

            curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);

            curl_exec($ch);
            curl_close($ch);
        }

        return true;
    }

    public function checkAvailability($id)
    {
        $data = $this->schedule->getDataById($id);
        if (is_null($data)) {
            throw new ServiceException('000');
        }

        return $data;
    }

    public function detail_schedule($id)
    {
        $data = $this->schedule->detail_schedule($id);
        return $data;
    }

    public function detail_schedule_count($id)
    {
        $this->checkAvailability($id);
        $data = $this->schedule->getDataAnalystHistoryById($id);
        $result = $this->checkAttendanceTraining($data);
        $unique_data = $this->unique_array($result);

        $total_attendance = 0;
        $complete_attendance = 0;
        $uncomplete_attendance = 0;
        foreach($unique_data as $dt)
        {
            $total_attendance += 1;
            if(is_null($dt['check_in']) || is_null($dt['check_out'])){
                $uncomplete_attendance += 1;
            } else {
                $complete_attendance += 1;
            }
        }

        return [
            'total' => $total_attendance,
            'complete' => $complete_attendance,
            'uncomplete' => $uncomplete_attendance
        ];
    }

    private function checkAttendanceTraining($data)
    {
        $temp = [];
        foreach ($data as $dt) {
            array_push($temp, [
                'agent' => $dt->agent->username,
                'agent_code' => $dt->agent->agent_code,
                'agent_pam' => is_null($dt->agent->referral) ? "None" : $dt->agent->referral->username,
                'check_in' => $dt->status_check === 1 ? $dt->time_check : null,
                'check_out' => $dt->status_check === 0 ? $dt->time_check : null
            ]);
        }

        return $temp;
    }

    private function unique_array($array1)
    {
        $agentCodeMap = [];
        
        foreach ($array1 as $item) {
            $agentCode = $item['agent_code'];
        
            if (!isset($agentCodeMap[$agentCode])) {
                $agentCodeMap[$agentCode] = $item;
            } else {
                if ($agentCodeMap[$agentCode]['check_out'] === null) {
                    $agentCodeMap[$agentCode]['check_out'] = $item['check_out'];
                }
            }
        }
        
        $expectedResult = array_values($agentCodeMap);
        return $expectedResult;
    }
}
