<?php

use Illuminate\Http\Request;

use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\SliderController;
use App\Http\Controllers\Admin\AgentController;
use App\Http\Controllers\Admin\HistoryController;
use App\Http\Controllers\Admin\ScheduleController;
use App\Http\Controllers\Admin\MenuController;
use App\Http\Controllers\Admin\MenuTypeController;
use App\Http\Controllers\Admin\NotificationController;
use App\Http\Controllers\Admin\Landing\SliderController as LandingSliderController;
use App\Http\Controllers\Admin\Landing\FormController as LandingFormController;
use App\Http\Controllers\Admin\Landing\SosialMediaController as LandingSosialMediaController;
use App\Http\Controllers\Admin\Landing\CallCenterController as LandingCallCenterController;
use App\Http\Controllers\Admin\PopupController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::prefix('admin')->group(function() {
    Route::post('login',[UserController::class, 'login'])->name('login');

    Route::middleware(['auth:sanctum'])->group(function () {
        Route::get('user_profile', function(Request $request) {
            return auth()->user();
        });
    
        // User
        Route::post('user/register',[UserController::class, 'register']);
        Route::get('user/index', [UserController::class, 'index']);
        Route::get('user/detail/{id}',[UserController::class, 'detail']);
        Route::post('user/update/{id}',[UserController::class, 'update']);
        Route::delete('user/disable/{id}',[UserController::class, 'disable']);
        Route::post('user/restore/{id}',[UserController::class, 'restore']);
        Route::post('user/logout', [UserController::class, 'logout']);
        
        // Agent
        Route::get('agent/index',[AgentController::class, 'index']);
        Route::post('agent/register',[AgentController::class, 'register']);
        Route::get('agent/detail/{id}',[AgentController::class, 'detail']);
        Route::post('agent/update/{id}',[AgentController::class, 'update']);
        Route::post('agent/update_password/{id}',[AgentController::class, 'update_password']);
        Route::delete('agent/disable/{id}',[AgentController::class, 'disable']);
        Route::post('agent/restore/{id}',[AgentController::class, 'restore']);
        Route::get('agent/new/index',[AgentController::class, 'index_new']);
        Route::post('agent/new/approve/{id}',[AgentController::class, 'approve']);
        Route::post('agent/new/reject/{id}',[AgentController::class, 'reject']);
    
        // Slider
        Route::get('slider/index',[SliderController::class, 'index']);
        Route::post('slider/store',[SliderController::class, 'store']);
        Route::get('slider/detail/{id}',[SliderController::class, 'detail']);
        Route::post('slider/update/{id}',[SliderController::class, 'update']);
        Route::delete('slider/delete/{id}',[SliderController::class, 'delete']);
        Route::post('slider/description_image/store',[SliderController::class, 'description_image']);
        Route::post('slider/update/display/{id}',[SliderController::class, 'update_display']);
    
        // Schedule
        Route::get('schedule/index',[ScheduleController::class, 'index']);
        Route::post('schedule/store',[ScheduleController::class, 'store']);
        Route::get('schedule/detail/{id}',[ScheduleController::class, 'detail']);
        Route::post('schedule/update/{id}',[ScheduleController::class, 'update']);
        Route::delete('schedule/delete/{id}',[ScheduleController::class, 'delete']);
        // Schedule - Analytics
        Route::post('schedule/analysis_history',[ScheduleController::class, 'analysis_history']);
        Route::get('schedule/analysis_history/detail/{id}',[ScheduleController::class, 'detail_analysis_history']);
        Route::get('schedule/analysis_history/detail/count/{id}',[ScheduleController::class, 'detail_schedule_count']);
        Route::get('schedule/analysis_history/detail_schedule/{id}',[ScheduleController::class, 'detail_schedule']);
        Route::post('schedule/analysis_history/filter',[ScheduleController::class, 'analysis_history_filter']);
        Route::get('schedule/chart',[ScheduleController::class, 'chart']);
        // Schedule - Notifications
        Route::post('schedule/notification/send/android/{id}',[ScheduleController::class, 'send_android']);
        Route::post('schedule/notification/send/ios/{id}',[ScheduleController::class, 'send_ios']);

        // History
        Route::post('history/index',[HistoryController::class, 'index']);
        Route::get('history/detail/{agent_id}/{start_date}/{end_date}',[HistoryController::class, 'detail']);
        Route::get('history/detail_person/{agent_id}/{start_date}/{end_date}',[HistoryController::class, 'detail_person']);
        Route::get('history/attendance',[HistoryController::class, 'attendance']);
        Route::get('history/attendance/detail/{agent_id}',[HistoryController::class, 'attendance_detail']);
       
        // Menu
        Route::get('menu/index',[MenuController::class, 'index']);
        Route::post('menu/store',[MenuController::class, 'store']);
        Route::get('menu/detail/{id}',[MenuController::class, 'detail']);
        Route::post('menu/update/{id}',[MenuController::class, 'update']);
        Route::delete('menu/delete/{id}',[MenuController::class, 'delete']);
        Route::get('menu/detail/child_menu/{id}',[MenuController::class, 'child_menu']);
        Route::post('menu/description_image/store',[MenuController::class, 'description_image']);
    
        // Menu Type
        Route::get('menu_type/index',[MenuTypeController::class, 'index']);
    
        // Notification
        Route::get('notification/index',[NotificationController::class, 'index']);
        Route::post('notification/store',[NotificationController::class, 'store']);
        Route::get('notification/detail/{id}',[NotificationController::class, 'detail']);
        Route::post('notification/update/{id}',[NotificationController::class, 'update']);
        Route::delete('notification/delete/{id}',[NotificationController::class, 'delete']);
        Route::post('notification/send/android/{id}',[NotificationController::class, 'send_android']);
        Route::post('notification/send/ios/{id}',[NotificationController::class, 'send_ios']);
        
        // Landing - Sliders
        Route::get('landing/slider/index',[LandingSliderController::class, 'index']);
        Route::post('landing/slider/store',[LandingSliderController::class, 'store']);
        Route::get('landing/slider/detail/{id}',[LandingSliderController::class, 'detail']);
        Route::post('landing/slider/update/{id}',[LandingSliderController::class, 'update']);
        Route::delete('landing/slider/delete/{id}',[LandingSliderController::class, 'delete']);
        Route::post('landing/slider/update/display/{id}',[LandingSliderController::class, 'update_display']);

        // Landing - Form
        Route::get('landing/form/index',[LandingFormController::class, 'index']);
        Route::post('landing/form/store',[LandingFormController::class, 'store']);
        Route::get('landing/form/detail/{id}',[LandingFormController::class, 'detail']);
        Route::post('landing/form/update/{id}',[LandingFormController::class, 'update']);
        Route::delete('landing/form/delete/{id}',[LandingFormController::class, 'delete']);
    
        // Landing - Sosial Media
        Route::get('landing/sosial_media/index', [LandingSosialMediaController::class, 'index']);
        Route::post('landing/sosial_media/update', [LandingSosialMediaController::class, 'update']);
    
        // Landing - Call Center
        Route::get('landing/call_center/index',[LandingCallCenterController::class, 'index']);
        Route::post('landing/call_center/update',[LandingCallCenterController::class, 'update']);
        Route::post('landing/call_center/description_image/store',[LandingCallCenterController::class, 'description_image']);

        // Pop up
        Route::get('pop_up/index',[PopupController::class, 'index']);
        Route::post('pop_up/update',[PopupController::class, 'update']);
        Route::post('pop_up/disable',[PopupController::class, 'disable']);
        Route::post('pop_up/restore',[PopupController::class, 'restore']);

        // Logout
        Route::post('logout', [UserController::class, 'logout'])->name('logout');
    });
});
